.. _api-field:

Field
-----

.. _api-field-value:

``value``
^^^^^^^^^

Returns the value stored in the field object.

.. _api-field-validators:

``validators``
^^^^^^^^^^^^^^

Returns a list of validators associated with the field.
